@@ -12,7 +12,7 @@ See `the FlickrAPI homepage`_ for more info.
 """
 from __future__ import unicode_literals
 
-# Copyright (c) 2007-2017 by the respective coders, see
+# Copyright (c) 2007-2018 by the respective coders, see
 # http://stuvel.eu/flickrapi
 #
 # This code is subject to the Python licence, as can be read on
@@ -44,13 +44,13 @@ from __future__ import unicode_literals
 from flickrapi.core import FlickrAPI
 
 from flickrapi.xmlnode import XMLNode
-from flickrapi.exceptions import IllegalArgumentException, \
-    FlickrError, CancelUpload, LockingError
+from flickrapi.exceptions import (IllegalArgumentException,
+    FlickrError, CancelUpload, LockingError)
 from flickrapi.cache import SimpleCache
-from flickrapi.tokencache import OAuthTokenCache, TokenCache, SimpleTokenCache, \
-    LockingTokenCache
+from flickrapi.tokencache import (OAuthTokenCache, TokenCache, SimpleTokenCache,  # noqa: F401
+    LockingTokenCache)
 
-__version__ = '2.3'
+__version__ = '2.4.0'
 __all__ = ('FlickrAPI', 'IllegalArgumentException', 'FlickrError',
            'CancelUpload', 'LockingError', 'XMLNode', 'set_log_level', '__version__',
            'SimpleCache', 'TokenCache', 'SimpleTokenCache', 'LockingTokenCache')
